@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=4.7.3
+gcc_version=4.8.0
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -33,6 +33,11 @@ done
 
 archive=${1-gcc-$gcc_version.tar.bz2}
 
+#
+#  Detect required tar command line parameters for unpacking source archice
+#
+tar_param=xf`case $archive in *.gz|*.tgz) echo 'z';; *.bz2) echo 'j';; *.xz) echo 'J';; esac`
+
 if test "$tar_param" = "xf" ; then
     echo "Failed to detect how to decompress $archive"
     exit 1
@@ -42,7 +47,7 @@ rm -rf gnu
 mkdir gnu
 
 rm -f $top/s-sources
-( cd gnu && tar xf $top/$archive --use=`case $archive in *.gz|*.tgz) echo 'gzip';; *.bz2) echo 'bzip2';; *.xz) echo 'xz';; esac` && echo $archive >$top/s-sources )
+( cd gnu && tar $tar_param $top/$archive && echo $archive >$top/s-sources )
 
 if ! [ -f s-sources ] ; then
     echo "Cannot unpack GCC sources"
